Opt

Struct Opt 

pub struct Opt<T>(pub T);
The optional combinator that never fails. If the inner combinator fails, the result is None.

Note

One might think that the Opt<T> combinator can be encoded as OrdChoice<T, Success>. However, this is not the case because one cannot prove that Success is disjoint from T. In fact, there is a fundamental difference between Opt<T> and OrdChoice<Fst, Snd>: the Disjoint conditions can be aggregated for OrdChoice, making it “nestable”, while the “productivity” condition cannot be aggregated for Opt (i.e., Opt<Opt<T>> can never be constructed).

Tuple Fields

0: T

Implementations

Source

impl<C: View> Opt<C>

pub exec fn new(c: C) -> o : Self

requires
c@.is_productive(),
ensures
o == Opt(c),

Constructs a new Opt combinator, only if the inner combinator is productive.